@@ -1,11 +1,11 @@
 
 mice_multilevel_imputation_blme_args <- function(lmer_args , blme_args){
 	if ( ! is.null( blme_args) ){
-		NL <- base::length(blme_args)
+		NL <- length(blme_args)
 		for (nn in 1:NL){
-			name_nn <- base::names(blme_args)[nn]
+			name_nn <- names(blme_args)[nn]
 			lmer_args[[ name_nn ]] <- blme_args[[ nn ]]	
 		}
 	}
-	base::return(lmer_args)
-}
\ No newline at end of file
+	return(lmer_args)
+}
